<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://www.kyantonius.com/spip',
'0_langue' => 'Indonesian [id]',
'0_liste' => 'kyantonius@gmail.com',
'0_mainteneur' => 'Kemas Antonius (kyantonius@gmail.com)',

// A
'access_interface_graphique' => 'Kembali ke tatap muka grafis lengkap',
'access_mode_texte' => 'Tampilkan tatap muka teks disederhana',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modifikasi artikel ini',
'admin_modifier_auteur' => 'Modifikasi penulis ini',
'admin_modifier_breve' => 'Modifikasi artikel berita ini',
'admin_modifier_mot' => 'Modifikasi kata kunci ini',
'admin_modifier_rubrique' => 'Modifikasi bagian ini',
'admin_recalculer' => 'Perbaharui halaman ini',
'afficher_trad' => 'tampilkan terjemahan',
'alerte_maj_impossible' => '<b>Peringatan!</b> Gagal memperbaharui database SQL ke versi @version@, mungkin karena ada masalah hak akses di database. Silakan hubungi ISP anda.',
'alerte_modif_info_concourante' => 'ATTENTION : Cette information a &eacute;t&eacute; modifi&eacute;e par ailleurs. La valeur actuelle est&nbsp;:', # NEW
'analyse_xml' => 'Pemroresan XML',
'annuler' => 'Batal',
'antispam_champ_vide' => 'Mohon biarkan kolom ini kosong:',
'articles_recents' => 'Artikel-artikel terbaru',
'avis_archive_incorrect' => 'berkas arsip bukanlah berkas SPIP yang sah',
'avis_archive_invalide' => 'berkas arsip tidak sah',
'avis_attention' => 'HATI-HATI!',
'avis_champ_incorrect_type_objet' => 'Nama kolom salah @name@ untuk obyek tipe @type@',
'avis_colonne_inexistante' => 'Kolom @col@ tidak ada',
'avis_echec_syndication_01' => 'Sindikasi gagal: berkas yang dipilih tidak dapat dibaca atau ia tidak menyediakan satu artikel pun.',
'avis_echec_syndication_02' => 'Sindikasi gagal: tidak dapat menjangkau berkas sindikasi situs ini.',
'avis_erreur' => 'Kesalahan: lihat di bawah\';',
'avis_erreur_connexion' => 'Kesalahan koneksi',
'avis_erreur_cookie' => 'masalah cookie',
'avis_erreur_fonction_contexte' => 'Kesalahan program. Fungsi ini tidak seharusnya berada di konteks ini.',
'avis_erreur_mysql' => 'kesalahan SQL',
'avis_erreur_sauvegarde' => 'Kesalahan di backup (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Kesulitan dalam memasuki area pribadi',

// B
'barre_a_accent_grave' => 'Masukkan huruf kapital A dengan aksen ukiran',
'barre_aide' => 'Gunakan jalan pintas typografis untuk memperbaiki tampilan anda',
'barre_e_accent_aigu' => 'Masukkan huruf kapital E dengan aksen akut',
'barre_eo' => 'Masukkan sebuah oe-ligature',
'barre_eo_maj' => 'Masukkan huruf kapital EO-ligature',
'barre_euro' => 'Masukkan simbol &euro;',
'barre_gras' => 'Ubah dalam {{tipe tebal}}',
'barre_guillemets' => 'Letakkan di antara "dua tanda kutip"',
'barre_guillemets_simples' => 'Letakkan di antara "tanda kutip tunggal"',
'barre_intertitre' => 'Ubah ke {{{subheading}}}',
'barre_italic' => 'Ubah dalam tipe {miring}',
'barre_lien' => 'Ubah dalam bentuk [tautan web->http://...]',
'barre_lien_input' => 'Silakan isi target tautan web anda (anda dapat memberikan sebuah URL internet dalam bentuk http://www.mysite.com atau cukup mencantumkan nomor artikel di situs ini).',
'barre_note' => 'Ubah ke [[Footnote]]',
'barre_paragraphe' => 'Cr&#233;er un paragraphe', # NEW
'barre_quote' => '<quote>Kutip sebuah pesan</quote>',
'bouton_ajouter_document' => 'TAMBAH DOKUMEN', # MODIF
'bouton_ajouter_image' => 'TAMBAH GAMBAR', # MODIF
'bouton_ajouter_image_document' => 'Ajouter une image ou&nbsp;un&nbsp;document', # NEW
'bouton_changer' => 'Modifikasi',
'bouton_chercher' => 'Pencarian',
'bouton_choisir' => 'Pilih',
'bouton_download' => 'Unduh',
'bouton_enregistrer' => 'Simpan',
'bouton_radio_desactiver_messagerie_interne' => 'Non aktifkan sistem pesan internal',
'bouton_radio_envoi_annonces' => 'Kirim pengumuman editorial',
'bouton_radio_non_envoi_annonces' => 'Jangan kirim pengumuman apa pun',
'bouton_radio_non_envoi_liste_nouveautes' => 'Jangan kirim daftar berita terbaru',
'bouton_recharger_page' => 'perbaharui halaman ini',
'bouton_telecharger' => 'Unggah',
'bouton_valider' => 'Kirim',

// C
'cal_apresmidi' => 'siang (p.m.)',
'cal_jour_entier' => 'sehari penuh',
'cal_matin' => 'pagi (a.m.)',
'cal_par_jour' => 'kalender harian',
'cal_par_mois' => 'kalender bulanan',
'cal_par_semaine' => 'kalender mingguan',
'choix_couleur_interface' => 'warna',
'choix_interface' => 'pilihan tatap muka',
'colonne' => 'Kolom',
'confirm_changer_statut' => 'Konfirmasi dibutuhkan: Anda telah memohon untuk mengganti status artikel ini. Apakah anda ingin menindaklanjutinya?',
'correcte' => 'benar',

// D
'date_aujourdhui' => 'hari ini',
'date_avant_jc' => 'B.C.',
'date_dans' => 'dalam @delai@',
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'besok',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@ at @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@ @annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => 'on @nomjour@ @date@',
'date_heures' => 'jam',
'date_hier' => 'kemarin',
'date_il_y_a' => '@delai@ yang lalu',
'date_jnum1' => '1',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Minggu',
'date_jour_1_abbr' => 'Mgu.',
'date_jour_1_initiale' => 'M.',
'date_jour_2' => 'Senin',
'date_jour_2_abbr' => 'Sen',
'date_jour_2_initiale' => 'S.',
'date_jour_3' => 'Selasa',
'date_jour_3_abbr' => 'Sel.',
'date_jour_3_initiale' => 'S.',
'date_jour_4' => 'Rabu',
'date_jour_4_abbr' => 'Rab.',
'date_jour_4_initiale' => 'R.',
'date_jour_5' => 'Kamis',
'date_jour_5_abbr' => 'Kam.',
'date_jour_5_initiale' => 'K.',
'date_jour_6' => 'Jumat',
'date_jour_6_abbr' => 'Jum.',
'date_jour_6_initiale' => 'J.',
'date_jour_7' => 'Sabtu',
'date_jour_7_abbr' => 'Sab.',
'date_jour_7_initiale' => 'S.',
'date_jours' => 'hari',
'date_minutes' => 'menit',
'date_mois' => 'bulan',
'date_mois_1' => 'Januari',
'date_mois_10' => 'Oktober',
'date_mois_11' => 'November',
'date_mois_12' => 'Desember',
'date_mois_2' => 'Februari',
'date_mois_3' => 'Maret',
'date_mois_4' => 'April',
'date_mois_5' => 'Mei',
'date_mois_6' => 'Juni',
'date_mois_7' => 'Juli',
'date_mois_8' => 'Agustus',
'date_mois_9' => 'September',
'date_saison_1' => 'musim dingin',
'date_saison_2' => 'musim semi',
'date_saison_3' => 'musim panas',
'date_saison_4' => 'musim gugur',
'date_secondes' => 'secondes', # NEW
'date_semaines' => 'minggu',
'date_un_mois' => 'mois', # NEW
'date_une_heure' => 'heure', # NEW
'date_une_minute' => 'minute', # NEW
'date_une_seconde' => 'seconde', # NEW
'date_une_semaine' => 'semaine', # NEW
'dirs_commencer' => ' untuk memulai proses instalasi sesungguhnya',
'dirs_preliminaire' => 'Pendahuluan: <b>Mengatur hak akses</b>',
'dirs_probleme_droits' => 'Masalah dalam hak akses',
'dirs_repertoires_absents' => '<b>Direktori-direktori berikut tidak ditemukan: <ul>@bad_dirs@.</ul> </b>
  <p>Kemungkinan penyebabnya adalah penggunaan huruf besar atau kecil.
  Pastikan bahwasanya huruf besar dan kecil dari direktori ini sesuai dengan yang ditampilkan
  di atas; jika tidak, ubah nama direktori menggunakan klien FTP untuk memperbaiki kesalahan.
  </p><p>Setelah ini selesai, anda dapat</p>',
'dirs_repertoires_suivants' => '<b>Direktori-direktori berikut tidak memiliki hak akses tulis: <ul>@bad_dirs@.</ul> </b>

  <p>Untuk menggantinya, gunakan klien FTP anda untuk menset hak akses setiap

  direktori tersebut. Prosedur secara rinci dapat dilihat di manual instalasi.

  </p><p>Setelah anda selesai melakukannya, anda dapat </p>',
'double_occurrence' => 'Entri ganda', # MODIF

// E
'en_cours' => 'en cours', # NEW
'entree_dimensions' => 'Ukuran:',
'entree_titre_document' => 'Judul dokumen:',
'entree_titre_image' => 'Judul gambar:',
'envoi_via_le_site' => 'Dikirim melalui situs',
'erreur' => 'Kesalahan',
'erreur_balise_non_fermee' => 'tag terakhir tidak ditutup:',
'erreur_texte' => 'kesalahan',
'etape' => '&Eacute;tape', # NEW

// F
'fichier_introuvable' => 'Berkas tidak ditemukan: @fichier@',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Anda telah terdaftar.',
'form_email_non_valide' => 'Alamat e-mail anda tidak sah.',
'form_forum_access_refuse' => 'Anda tidak memiliki akses ke situs ini lagi.',
'form_forum_bonjour' => 'Salam sejahtera @nom@,',
'form_forum_email_deja_enregistre' => 'Alamat e-mail ini telah terdaftar, oleh karenanya anda dapat menggunakan kata sandi anda.',
'form_forum_identifiant_mail' => 'Pengidentifikasi baru anda telah dikirimkan kepada anda melalui e-mail.',
'form_forum_identifiants' => 'Pengidentifikasi pribadi',
'form_forum_indiquer_nom_email' => 'Masukkan nama dan alamat e-mail anda. Anda akan menerima pengidentifikasi pribadi anda segera melalui e-mail.',
'form_forum_login' => 'log masuk:',
'form_forum_message_auto' => '(ini adalah sebuah pesan terotomasi)',
'form_forum_pass' => 'kata sandi:',
'form_forum_probleme_mail' => 'Permasalahan e-mail: pengidentifikasi tidak dapat dikirim.',
'form_forum_voici1' => 'Ini pengidentifikasi anda  untuk berpartisipasi dalam kehidupan situs
"@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Ini pengidentifikasi anda untuk mengirimkan artikel untuk situs "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Silakan masukkan alamat e-mail anda.',
'form_indiquer_nom' => 'Silakan masukkan nama anda.',
'form_indiquer_nom_site' => 'Silakan masukkan nama situs anda.',
'form_pet_adresse_site' => 'URL situs anda',
'form_pet_aucune_signature' => 'Tidak ada tanda tangan yang cocok dengan kode ini...',
'form_pet_confirmation' => 'Silakan konfirmasi tanda tangan anda:',
'form_pet_deja_enregistre' => 'Situs ini telah terdaftar',
'form_pet_deja_signe' => 'Anda telah menandatangani teks ini.',
'form_pet_envoi_mail_confirmation' => 'Sebuah e-mail konfirmasi telah dikirimkan kepada anda. Anda harus mengunjungi URL yang tercantum dalam email ini untuk menvalidasi tanda tangan anda.', # MODIF
'form_pet_mail_confirmation' => 'Halo,

Anda telah menandatangani petisi:
@titre@.

Anda memberikan informasi berikut:
    Nama: @nom_email@
    Situs: @nom_site@ - @url_site@
@message@

PESAN...
Untuk menvalidasi tanda tangan anda, anda hanya perlu mengunjungi
alamat di bawah (atau permohonan anda
akan ditolak):
    @url@

Terima kasih atas partisipasi anda!
',
'form_pet_message_commentaire' => 'Ada pesan atau komentar?',
'form_pet_nom_site2' => 'Nama situs web anda',
'form_pet_probleme_liens' => 'Veuillez reprendre votre message en supprimant les liens hypertexte.', # NEW
'form_pet_probleme_technique' => 'Permasalahan teknis, sistem tanda tangan untuk sementara waktu terganggu.',
'form_pet_signature_pasprise' => 'Tanda tangan anda tidak dihiraukan.',
'form_pet_signature_validee' => 'Tanda tangan anda sah. Terima kasih!',
'form_pet_site_deja_enregistre' => 'Situs ini telah terdaftar',
'form_pet_url_invalide' => 'URL yang anda berikan tidak sah.',
'form_pet_votre_email' => 'Alamat e-mail anda',
'form_pet_votre_nom' => 'Nama atau alias anda',
'form_pet_votre_site' => 'Jika anda memiliki sebuah situs web, anda dapat memasukkannya di bawah',
'form_prop_confirmer_envoi' => 'Konfirmasi dispatch',
'form_prop_description' => 'Deskripsi/komentar',
'form_prop_enregistre' => 'Proposal anda telah disimpan, dan akan muncul secara online setelah divalidasi oleh administrator situs ini.',
'form_prop_envoyer' => 'Kirim sebuah pesan',
'form_prop_indiquer_email' => 'Silakan masukkan alamat e-mail yang sah',
'form_prop_indiquer_nom_site' => 'Silakan masukkan nama situs.',
'form_prop_indiquer_sujet' => 'Silakan masukkan sebuah subyek',
'form_prop_message_envoye' => 'Pesan terkirim',
'form_prop_nom_site' => 'Nama situs',
'form_prop_non_enregistre' => 'Proposal anda tidak disimpan.',
'form_prop_sujet' => 'Subyek',
'form_prop_url_site' => 'URL situs',
'forum_acces_refuse' => 'Anda tidak memiliki akses ke forum ini lagi.',
'forum_attention_dix_caracteres' => '<b>Peringatan!</b> Pesan anda hendaknya terdiri dari sepuluh karakter atau lebih.',
'forum_attention_trois_caracteres' => '<b>Peringatan!</b> Judul anda hendaknya terdiri dari tiga karakter atau lebih.',
'forum_attention_trop_caracteres' => '<b>Peringatan&nbsp;!</b> pesan anda terlalu panjang (@compte@ karakter)&nbsp;: untuk dapat menyimpannya, pesan tidak boleh lebih dari @max@ karakter.',
'forum_avez_selectionne' => 'Anda telah memilih:',
'forum_cliquer_retour' => 'Klik  <a href=\'@retour_forum@\'>di sini</a> untuk lanjut.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Forum ini telah dimoderasi: kontribusi anda hanya akan muncul setelah divalidasi oleh administrator situs.',
'forum_lien_hyper' => '<b>Tautan web</b> (opsional)',
'forum_message_definitif' => 'Pesan akhir: kirim ke situs',
'forum_message_trop_long' => 'Pesan anda terlalu panjang. Panjang maksimum adalah 20000 karakter.',
'forum_ne_repondez_pas' => 'Jangan balas ke e-mail ini tapi ke forum yang terdapat di alamat berikut:',
'forum_non_inscrit' => 'Anda belum terdaftar atau alamat atau kata sandi yang salah.',
'forum_page_url' => '(Jika pesan anda merujuk pada sebuah artikel yang dipublikasi di web atau halaman yang memberikan informasi lebih lanjut, silakan masukkan judul halaman dan URL-nya di bawah).',
'forum_par_auteur' => 'oleh @auteur@',
'forum_poste_par' => 'Pesan dikirim@parauteur@ mengikuti artikel anda.',
'forum_probleme_database' => 'Permasalahan database, pesan anda tidak dapat disimpan.',
'forum_qui_etes_vous' => '<b>Siapa anda?</b> (opsional)',
'forum_texte' => 'Teks pesan anda:',
'forum_titre' => 'Subyek:',
'forum_titre_erreur' => 'Kesalahan...',
'forum_url' => 'URL:',
'forum_valider' => 'Validasi pilihan ini',
'forum_voir_avant' => 'Lihat pesan sebelum dikirim',
'forum_votre_email' => 'Alamat e-mail anda:',
'forum_votre_nom' => 'Nama anda (atau alias):',
'forum_vous_enregistrer' => 'Sebelum berpartisipasi di
		forum ini, anda harus mendaftarkan diri. Terima kasih
		telah memasukkan pengidentifikasi pribadi yang
		diberikan pada anda. Jika anda belum terdaftar, anda harus',
'forum_vous_inscrire' => 'mendaftarkan diri.',

// I
'ical_texte_rss_articles' => 'Alamat berkas sindikasi artikel situs adalah:',
'ical_texte_rss_articles2' => 'Selain itu, anda juga dapat memperoleh berkas sindikasi untuk artikel dari setiap bagian situs:',
'ical_texte_rss_breves' => 'Selanjutnya, terdapat sebuah berkas yang berisikan artikel berita situs. Dengan memilih satu nomor bagian, anda dapat memperoleh artikel berita dari bagian tersebut.',
'icone_a_suivre' => 'Papan peluncur',
'icone_admin_site' => 'Administrasi situs',
'icone_agenda' => 'Kalender',
'icone_aide_ligne' => 'Bantuan',
'icone_articles' => 'Artikel',
'icone_auteurs' => 'Penulis',
'icone_breves' => 'Berita',
'icone_brouteur' => 'Jelajah cepat',
'icone_configuration_site' => 'Konfigurasi',
'icone_configurer_site' => 'Konfigurasi situs anda',
'icone_creer_nouvel_auteur' => 'Buat seorang penulis baru',
'icone_creer_rubrique' => 'Buat sebuah bagian',
'icone_creer_sous_rubrique' => 'Buat sebuah sub bagian',
'icone_deconnecter' => 'Log keluar',
'icone_discussions' => 'Diskusi',
'icone_doc_rubrique' => 'Lampiran',
'icone_ecrire_article' => 'Tulis artikel baru',
'icone_edition_site' => 'Edit situs',
'icone_forum_administrateur' => 'Forum administrator',
'icone_forum_suivi' => 'Tindak lanjut forum',
'icone_gestion_langues' => 'Manajemen bahasa',
'icone_informations_personnelles' => 'Informasi pribadi',
'icone_interface_complet' => 'tatap muka lengkap',
'icone_interface_simple' => 'Tatap muka disederhana',
'icone_maintenance_site' => 'Pemeliharaan situs',
'icone_messagerie_personnelle' => 'Sistem pesan pribadi',
'icone_mots_cles' => 'Kata-kata kunci',
'icone_nouvelle_breve' => 'Tulis sebuah artikel berita baru',
'icone_repartition_actuelle' => 'Tampilkan distribusi sekarang',
'icone_repartition_debut' => 'Tampilkan distribusi dari awal',
'icone_repartition_visites' => 'Distribusi kunjungan',
'icone_rubriques' => 'Bagian',
'icone_sauver_site' => 'Backup situs',
'icone_site_entier' => 'Seluruh situs',
'icone_sites_references' => 'Situs-situs referensi',
'icone_statistiques' => 'Statistik situs',
'icone_statistiques_visites' => 'Statistik',
'icone_suivi_activite' => 'Tindak lanjut aktivitas situs',
'icone_suivi_actualite' => 'Statistik situs',
'icone_suivi_forums' => 'Kelola forum',
'icone_suivi_pettions' => 'Kelola petisi',
'icone_suivi_revisions' => 'Revisi artikel',
'icone_supprimer_document' => 'Hapus dokumen ini',
'icone_supprimer_image' => 'Hapus gambar ini',
'icone_supprimer_message' => 'Hapus pesan ini',
'icone_tous_articles' => 'Semua artikel anda',
'icone_tous_auteur' => 'Semua penulis',
'icone_valider_message' => 'Validasi pesan ini',
'icone_visiter_site' => 'Kunjungi situs',
'icone_voir_en_ligne' => 'Lihat online',
'image_tourner_180' => 'Putar 180&deg;',
'image_tourner_droite' => 'Putar 90&deg; kanan',
'image_tourner_gauche' => 'Putar 90&deg; kiri',
'img_indisponible' => 'gambar tidak tersedia',
'impossible' => 'tidak mungkin',
'info_a_suivre' => 'PAPAN PELUNCUR&raquo;',
'info_a_valider' => '[akan divalidasi]',
'info_acces_interdit' => 'Akses terlarang',
'info_acces_refuse' => 'Akses ditolak',
'info_action' => 'Aksi: @action@',
'info_administrer_rubriques' => 'Anda dapat mengelola bagian ini dan sub-sub bagiannya',
'info_adresse_non_indiquee' => 'Anda tidak menentukan sebuah alamat untuk dites!',
'info_aide' => 'BANTUAN:',
'info_ajouter_mot' => 'Tambahkan kata kunci ini',
'info_annonce' => 'PENGUMUMAN',
'info_annonces_generales' => 'Pemberitahuan umum:',
'info_article_propose' => 'Artikel dikirim',
'info_article_publie' => 'Artikel dipublikasi',
'info_article_redaction' => 'Artikel dalam proses',
'info_article_refuse' => 'Artikel ditolak',
'info_article_supprime' => 'Artikel dihapus',
'info_articles' => 'Artikel',
'info_articles_a_valider' => 'Artikel yang akan divalidasi',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Artikel dikirim',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'penulis:',
'info_authentification_ftp' => 'Ototentikasi (dengan FTP).',
'info_bloquer_lien' => 'Blokir tautan ini',
'info_breves_02' => 'Berita',
'info_breves_2' => 'berita',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Artikel berita yang akan divalidasi',
'info_connexion_refusee' => 'Koneksi ditolak',
'info_contact_developpeur' => 'Silakan hubungi pengembang.',
'info_contenance' => 'Situs ini berisikan:',
'info_contribution' => 'kontribusi forum',
'info_copyright' => '@spip@ adalah piranti lunak bebas yang didistribusi @lien_gpl@.',
'info_copyright_doc' => 'Untuk informasi lebih lanjut, kunjungi <a href="@spipnet@">http://www.spip.net/en</a>.', # MODIF
'info_copyright_gpl' => 'di bawah lisensi GPL',
'info_cours_edition' => 'Artikel anda dalam proses',
'info_creer_repertoire' => 'Silakan buat sebuah berkas atau direktori yang diberi nama:',
'info_creer_repertoire_2' => 'dalam sub directori <b>@repertoire@</b>, kemudian',
'info_creer_vignette' => 'pembuatan otomatis gambar kecil',
'info_deplier' => 'Tidak dilipat',
'info_descriptif_nombre' => 'deskripsi:',
'info_description' => 'Deskripsi:',
'info_description_2' => 'Deskripsi:',
'info_dimension' => 'Ukuran:',
'info_document' => 'Dokumen',
'info_document_indisponible' => 'Ce document n\'est pas disponible', # NEW
'info_documents' => 'Dokumen',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP mengizinkan pertukaran pesan dan pembuatan forum
		diskusi pribadi di antara pengunjung situs. Anda dapat mengaktifkan
		atau menonaktifka fitur ini.',
'info_ecire_message_prive' => 'Tulis pesan pribadi',
'info_email_invalide' => 'Alamat e-mail tidak sah.',
'info_en_cours_validation' => 'Artikel anda dalam proses',
'info_en_ligne' => 'Online sekarang:',
'info_envoyer_message_prive' => 'Kirim pesan pribadi ke penulis ini',
'info_erreur_requete' => 'Kesalahan dalam query:',
'info_erreur_squelette2' => 'Tidak ada templat <b>@fichier@</b>...',
'info_erreur_systeme' => 'Kesalahan sistem (errno @errsys@)',
'info_erreur_systeme2' => 'Hard disk kemungkinan penuh atau database rusak. <br>
 <font color=\'red\'>coba <a href=\'@script@\'>perbaiki database</a>,
 atau hubungi hosting anda.</font>',
'info_fini' => 'Selesai!',
'info_format_image' => 'Format gambar yang digunakan untuk pembuatan gambar-gambar kecil: @gd_formats@.',
'info_format_non_defini' => 'format tidak dikenal',
'info_grand_ecran' => 'Tampilan besar',
'info_image_aide' => 'BANTUAN',
'info_image_process_titre' => 'Bagaimana membuat gambar-gambar kecil',
'info_impossible_lire_page' => '<b>Kesalahan!</b> Halaman tidak dapat dibaca <tt><html>@test_proxy@</html></tt> melalui proxy <tt>',
'info_inclusion_directe' => 'Penambahan langsung:',
'info_inclusion_vignette' => 'Ikutkan gambar kecil:',
'info_installation_systeme_publication' => 'Instalasi sistem publikasi ...',
'info_installer_documents' => 'Anda dapat menginstal secara otomatis semua dokumen yang berada dalam direktori @upload@.',
'info_installer_ftp' => 'Sebagai administrator, anda dapat menginstal (dengan FTP) berkas-berkas dalam direktori @upload@ agar dapat memilih berkas langsung dari sini nantinya.',
'info_installer_images' => 'Anda dapat menginstal gambar dengan format JPEG, GIF atau PNG.',
'info_installer_images_dossier' => 'Instal gambar dalam direktori @upload@ agar dapat dipilih di sini.',
'info_installer_tous_documents' => 'Instal semua dokumen',
'info_interface_complete' => 'tatap muka lengkap',
'info_interface_simple' => 'Tatap muka disederhana',
'info_joindre_document_article' => 'Anda dapat melampirkan di artikel anda tipe-tipe dokumen',
'info_joindre_document_rubrique' => 'Anda dapat menambah ke bagian ini tipe-tipe dokumen',
'info_joindre_documents_article' => 'Anda dapat melampirkan di artikel anda tipe-tipe dokumen:',
'info_l_article' => 'article',
'info_la_breve' => 'artikel berita',
'info_la_rubrique' => 'bagian',
'info_langue_principale' => 'Bahasa situs utama',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'oleh @les_auteurs@',
'info_logo_format_interdit' => 'Hanya logo-logo dalam format @formats@ diperbolehkan.',
'info_logo_max_poids' => 'Logo hendaklan kurang dari @maxi@ (berkas ini @actuel@).',
'info_logo_max_taille' => 'Logo hendaklah kurang dari @maxi@ (berkas ini @actuel@).',
'info_mail_fournisseur' => 'you@isp.com',
'info_message_2' => 'PESAN',
'info_message_supprime' => 'PESAN DIHAPUS',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Tanggal publikasi online:',
'info_modification_parametres_securite' => 'modifikasi parameter-parameter keamanan',
'info_mois_courant' => 'Selama bulan:',
'info_mot_cle_ajoute' => 'Kata kunci berikut ditambahkan ke',
'info_multi_herit' => 'Bahasa standar',
'info_multi_langues_soulignees' => '<u>Bahasa yang digarisbawahi</u> menyediakan terjemahan untuk semua teks tatap muka. Jika anda memilih bahasa-bahasa ini, sebagian besar elemen situs umum (tanggal-tanggal, formulir-formulir) akan diterjemahkan secara otomatis. Untuk bahasa yang tidak bergaris bawah, elemen-elemen tersebut akan muncul dalam bahasa utama situs.',
'info_multilinguisme' => 'Multi bahasa',
'info_nom_non_utilisateurs_connectes' => 'Nama anda tidak muncul di daftar pengguna yang terkoneksi.',
'info_nom_utilisateurs_connectes' => 'Nama anda muncul dalam daftar pengguna yang terkoneksi.',
'info_nombre_en_ligne' => 'Online sekarang:',
'info_non_resultat' => 'Tidak ada hasil untuk "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Anda tidak sedang menggunakan sistem pesan pribadi situs ini.',
'info_nouveau_message' => 'ANDA MEMILIKI SEBUAH PESAN BARU',
'info_nouveaux_messages' => 'ANDA MEMILIKI @total_messages@ PESAN BARU',
'info_numero_abbreviation' => 'Tidak',
'info_obligatoire' => 'Cette information est obligatoire', # NEW
'info_panne_site_syndique' => 'Situs-situs sindikasi tidak dapat dijangkau',
'info_pense_bete' => 'MEMO',
'info_petit_ecran' => 'Tampilan kecil',
'info_petition_close' => 'P&eacute;tition close', # NEW
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Beberapa kata kunci ditemukan untuk "@cherche_mot@":',
'info_popularite_5' => 'popularitas:',
'info_portfolio' => 'Portfolio',
'info_portfolio_automatique' => 'Portfolio terotomasi:',
'info_premier_resultat' => '[@debut_limit@ hasil pertama dari @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ hasil pertama dari @total@]',
'info_probleme_grave' => 'kesalahan',
'info_propose_1' => '[@nom_site_spip@] Dikirim: @titre@',
'info_propose_2' => 'Artikel dikirim
-----------------',
'info_propose_3' => 'Artikel "@titre@" dikirim untuk publikasi.',
'info_propose_4' => 'Anda diundang untuk mengulasnya dan memberikan opini anda',
'info_propose_5' => 'dalam forum yang terkait, yang tersedia di alamat:',
'info_publie_01' => 'Artikel "@titre@" divalidasi oleh @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] DIPUBLIKASI: @titre@',
'info_publie_2' => 'Artikel dipublikasi
-----------------',
'info_rechercher' => 'Pencarian',
'info_rechercher_02' => 'Pencarian:',
'info_remplacer_vignette' => 'Ganti gambar kecil standar dengan sebuah logo yang disediakan:',
'info_retablir_lien' => 'pulihkan tautan ini',
'info_retirer_mot' => 'Hapus kata kunci ini',
'info_retirer_mots' => 'Hapus semua kata kunci',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'tidak berjudul',
'info_selectionner_fichier' => 'Anda dapat memilih sebuah berkas dari direktori @upload@',
'info_selectionner_fichier_2' => 'Pilih sebuah berkas:',
'info_signature_supprimee' => 'Signature supprim&eacute;e', # NEW
'info_signature_supprimee_erreur' => 'Erreur&nbsp;: ce code de suppression ne correspond a aucune signature', # NEW
'info_site_attente' => 'Validasi tertunda situs web',
'info_site_reference' => 'Situs-situs referensi online',
'info_site_refuse' => 'Situs web ditolak',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Merujuk sebuah situs',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'hapus gambar kecil',
'info_symbole_bleu' => 'Simbol <b>biru</B> menandakan sebuah <b>memo</B>: yakni sebuah pesan untuk penggunaan pribadi anda.',
'info_symbole_jaune' => 'Simbol <b>kuning</B> menandakan sebuah <b>pengumuman untuk semua edtor</B>: dapat diedit oleh semua administrator, dan muncul pada semua editor.',
'info_symbole_vert' => 'Simbol <b>hijau</B> menandakan <b>pesan yang diperoleh dari pengguna lainnya</B> di situs.',
'info_syndication' => 'sindikasi:',
'info_syndication_articles' => 'artikel',
'info_telecharger' => 'Unggah dari komputer anda:',
'info_telecharger_nouveau_logo' => 'Unggah logo baru:',
'info_telecharger_ordinateur' => 'Unggah dari komputer anda:',
'info_tous_resultats_enregistres' => '[semua hasil disimpan]',
'info_tout_afficher' => 'Tampilkan semua',
'info_travaux_texte' => 'Situs ini belum dibuat. Silakan kembali beberapa waktu kemudian...',
'info_travaux_titre' => 'Situs dalam pengembangan',
'info_trop_resultat' => 'Terlalu banyak hasil untuk "@cherche_mot@"; silakan perbaiki pencarian anda.',
'info_utilisation_messagerie_interne' => 'Anda sedang menggunakan sistem pesan internal situs ini.',
'info_valider_lien' => 'validasi tautan ini',
'info_verifier_image' => ', pastikan gambar anda telah ditransfer secara benar.',
'info_vignette_defaut' => 'Gambar kecil standar',
'info_vignette_personnalisee' => 'Gambar kecil yang dikustomisasi',
'info_visite' => 'kunjungan:',
'info_visites' => 'kunjungan:',
'info_vos_rendez_vous' => 'Janji-janji anda yang akan datang',
'info_zoom' => 'perbesar',
'infos_vos_pense_bete' => 'Memo anda',
'item_breve_proposee' => 'Artikel berita dikirim',

// L
'lien_afficher_icones_seuls' => 'Tampilkan icon saja',
'lien_afficher_texte_icones' => 'Tampilkan icon dan teks',
'lien_afficher_texte_seul' => 'Tampilkan teks saja',
'lien_liberer' => 'rilis',
'lien_liberer_tous' => 'bebaskan artikel-artikel ini',
'lien_nouvea_pense_bete' => 'MEMO BARU',
'lien_nouveau_message' => 'PESAN BARU',
'lien_nouvelle_annonce' => 'PENGUMUMAN BARU',
'lien_petitions' => 'PETISI',
'lien_popularite' => 'popularitas: @popularite@%',
'lien_racine_site' => 'ROOT SITUS',
'lien_reessayer' => 'coba lagi',
'lien_repondre_message' => 'Balas pesan ini',
'lien_supprimer' => 'hapus',
'lien_tout_afficher' => 'Tampilkan semua',
'lien_visite_site' => 'kunjungi situs ini',
'lien_visites' => '@visites@ kunjungan',
'lien_voir_auteur' => 'Cek penulis ini',
'ligne' => 'Baris',
'login' => 'Connexion', # NEW
'login_acces_prive' => 'akses ke area pribadi',
'login_autre_identifiant' => 'gunakan ID lain',
'login_cookie_accepte' => 'Silakan set browser anda untuk menerimanya (paling tidak untuk situs ini).',
'login_cookie_oblige' => 'Untuk mengidentifikasi diri anda secara aman, anda harus menerima cookie.',
'login_deconnexion_ok' => 'Keluar.',
'login_erreur_pass' => 'Kesalahan kata sandi.',
'login_espace_prive' => 'area pribadi',
'login_identifiant_inconnu' => 'Pengidentifikasi "@login@" tidak dikenal.',
'login_login' => 'Log masuk:',
'login_login2' => 'Log masuk (pengidentifikasi untuk koneksi ke situs):',
'login_login_pass_incorrect' => '(Log masuk atau kata sandi salah).',
'login_motpasseoublie' => 'lupa kata sandi?',
'login_non_securise' => 'Berhati-hatilah, formulir ini tidak aman.
   Jika anda tidak ingein kata sandi anda diketahui sewaktu
   melewati jaringan, aktifkan Javascript
   di browser anda dan',
'login_nouvelle_tentative' => 'Percobaan baru',
'login_par_ici' => 'Anda telah terdaftar... dengan ini...',
'login_pass2' => 'Kata sandi:',
'login_preferez_refuser' => '<b>Jika anda hendak menolak cookir</b>, tersedia metode koneksi lainnya (kurang aman) yang dapat anda gunakan:',
'login_recharger' => 'perbaharui halaman ini',
'login_rester_identifie' => 'Ingat ID saya untuk beberapa hari',
'login_retour_public' => 'Kembali ke situs umum',
'login_retour_site' => 'Kembali ke situs umum',
'login_retoursitepublic' => 'kembali ke situs umum',
'login_sans_cookiie' => 'Identifikasi tanpa cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'daftar',
'login_test_navigateur' => 'mencoba browser/koneksi',
'login_verifiez_navigateur' => '(Bagaimana pun, verifikasi bahwasanya browser anda tidak menyimpan kata sandi anda...)',

// M
'masquer_colonne' => 'Masquer cette colonne', # NEW
'masquer_trad' => 'sembunyikan terjemahan',
'module_fichiers_langues' => 'Berkas-berkas bahasa',

// N
'navigateur_pas_redirige' => 'Jika browser anda tidak dialihkan, klik di sini untuk lanjut.',
'numero' => 'Nomor',

// O
'occurence' => 'peristiwa',
'onglet_affacer_base' => 'Hapus database',
'onglet_auteur' => 'Penulis',
'onglet_contenu_site' => 'Isi situs',
'onglet_evolution_visite_mod' => 'Tingkat kunjungan',
'onglet_fonctions_avances' => 'Fungsi-fungsi lanjutan',
'onglet_informations_personnelles' => 'Informasi pribadi',
'onglet_interactivite' => 'Interaktivitas',
'onglet_messagerie' => 'Sistem pesan',
'onglet_messages_internes' => 'Pesan internal',
'onglet_messages_publics' => 'Pesan umum',
'onglet_messages_vide' => 'Pesan tanpa teks',
'onglet_origine_visites' => 'Kunjungan asal',
'onglet_repartition_debut' => 'dari awal',
'onglet_repartition_lang' => 'Distribusi berdasarkan bahasa',
'onglet_repartition_rubrique' => 'Distribusi berdasarkan bagian',
'onglet_save_restaur_base' => 'Backup/pulihkan database',
'onglet_vider_cache' => 'Kosongkan cache',
'ortho_trop_de_fautes2' => 'Mulai dari mengkoreksi kesalahan-kesalahan yang paling kentara, kemudian coba lagi.',

// P
'pass_choix_pass' => 'Silakan pilih kata sandi baru anda:',
'pass_erreur' => 'Kesalahan',
'pass_erreur_acces_refuse' => '<b>Kesalahan:</b> anda tidak memiliki akses ke situs ini lagi.',
'pass_erreur_code_inconnu' => '<b>Kesalahan:</b> kode ini tidak sesuai dengan pengunjung yang memiliki hak akses ke situs ini.',
'pass_erreur_non_enregistre' => '<b>Kesalahan:</b> alamat <tt>@email_oubli@</tt> tidak terdaftar di situs ini.',
'pass_erreur_non_valide' => '<b>Kesalahan:</b> e-mail <tt>@email_oubli@</tt> tidak sah!',
'pass_erreur_probleme_technique' => '<b>Kesalahan:</b> e-mail ini tidak dapat dikirim karena persoalan teknis.',
'pass_espace_prive_bla' => 'Area pribadi situs ini terbuka untuk
pengunjung setelah registrasi. Sekali terdaftar,
anda dapat mengulas artikel yang sedang diproses,
mengirim artikel dan berpartisipasi dalam semua forum.',
'pass_forum_bla' => 'Anda memohon untuk berpartisipasi dalam forum
yang diperuntukkan untuk pengunjung terdaftar.',
'pass_indiquez_cidessous' => 'Masukkan di bawah alamat e-mail yang anda
gunakan mendaftar dahulu. Anda akan
menerima sebuah e-mail yang menjelaskan bagaimana anda
mendapatkan akses anda.',
'pass_mail_passcookie' => '(ini adalah pesan terotomasi)

Untuk memperoleh akses anda ke situs
@nom_site_spip@ (@adresse_site@)

Silakan kunjungi alamat berikut:
    @sendcookie@

Anda dapat memasukkan kata sandi baru
dan mengakses situs kembali.
',
'pass_mot_oublie' => 'Kata sandi lupa',
'pass_nouveau_enregistre' => 'Kata sandi baru anda telah disimpan.',
'pass_nouveau_pass' => 'Kata sandi baru',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Lupa kata sandi',
'pass_quitter_fenetre' => 'Keluar dari layar ini',
'pass_rappel_login' => 'Pengingat: pengidentifikasi (log masuk) anda adalah "@login@".',
'pass_recevoir_mail' => 'Anda akan menerima sebuah e-mail yang menjelaskan bagaimana anda mendapatkan akses anda ke situs.',
'pass_retour_public' => 'Kembali ke situs umum',
'pass_rien_a_faire_ici' => 'Tidak ada yang dapat dilakukan di sini.',
'pass_vousinscrire' => 'Mendaftar dengan situs',
'precedent' => 'sebelumnya',
'previsualisation' => 'Preview',
'previsualiser' => 'Tampilkan preview',

// R
'retour' => 'Kembali',

// S
'spip_conforme_dtd' => 'SPIP menemukan bahwasanya halaman ini sesuai dengan DOCTYPE-nya:',
'squelette' => 'templat',
'squelette_inclus_ligne' => 'templat yang diikutsertakan, baris',
'squelette_ligne' => 'templat, baris',
'stats_visites_et_popularite' => '@visites@ kunjungan; popularitas: @popularite@',
'suivant' => 'selanjutnya',

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Ketika anda menjadi familiar dengan tatap muka yang ada, kliklah &laquo;',
'texte_actualite_site_2' => 'tatap muka lengkap',
'texte_actualite_site_3' => '&raquo; untuk fitur-fitur yang lebih banyak.',
'texte_creation_automatique_vignette' => 'Pembuatan otomatis preview gambar kecil diaktifkan di situs ini. Jika anda menginstal, melalui formulir ini, gambar dalam format @gd_formats@, ia akan disandingkan dengan gambar kecil yang berukuran maksimum @taille_preview@ pixels.',
'texte_documents_associes' => 'Dokumen berikut diasosiasikan dengan artikel,
				tapi tidak dimasukkan secara langsung.
				Sesuai dengan tampilan situs umum,
				mereka dapat muncul sebagai lampiran.',
'texte_erreur_mise_niveau_base' => 'Kesalahan database sewaktu pembaharuan.
						Gambar <b>@fichier@</B> tidak dapat diteruskan (artikel @id_article@).<p>
						Perhatikan dengan seksama referensi ini, ulangi prosedur pembaharuan,
						dan pastikan gambar akhirnya muncul
						di artikel.',
'texte_erreur_visiteur' => 'Anda telah mencoba memasuki area pribadi dengan log masuk yang tidak sah.',
'texte_inc_auth_1' => 'Anda mengidentifikasikan diri anda dengan log masuk
		<b>@auth_login@</B>, tapi tidak dapat ditemukan di database (lagi). 
		Coba untuk', # MODIF
'texte_inc_auth_2' => 'akses kembali',
'texte_inc_auth_3' => 'keluar, dan
		buka kembali browser anda jika perlu.',
'texte_inc_config' => 'Modifikasi yang dibuat di bawah akan mempengaruhi
	 fungsi situs. Anda dianjurkan untuk tidak melakukannya terkecuali bila anda
	telah mengenal sistem SPIP dengan baik. <P align="justify"><b>Biasanya,
	pekerjaan ini dapat anda serahkan kepada webmaster yang tentunya
	lebih paham SPIP daripada anda.</b>',
'texte_inc_meta_1' => 'Sistem mengalami kesulitan ketika mencoba melakukan penulisan terhadap berkas <code>@fichier@</code>. Sebagai administrator situs, silakan',
'texte_inc_meta_2' => 'verifikasi hak akses tulis',
'texte_inc_meta_3' => 'direktori <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'pengeditan dalam proses',
'texte_statut_poubelle' => 'dalam keranjang sampah',
'texte_statut_propose_evaluation' => 'dikirim untuk evaluasi',
'texte_statut_publie' => 'dipublikasi online',
'texte_statut_refuse' => 'ditolak',
'titre_ajouter_mot_cle' => 'TAMBAH SEBUAH KATA KUNCI:',
'titre_breve_proposee' => 'Artikel berita yang dikirim',
'titre_breve_publiee' => 'Artikel berita dipublikasi',
'titre_breve_refusee' => 'Artikel berita ditolak',
'titre_cadre_raccourcis' => 'JALAN PINTAS:',
'titre_changer_couleur_interface' => 'Mengubah warna tatap muka',
'titre_forum' => 'Forum',
'titre_image_admin_article' => 'Anda dapat mengelola artikel ini',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Bantuan pada item ini',
'titre_image_auteur_supprime' => 'Penulis dihapus',
'titre_image_redacteur' => 'Editor tanpa akses',
'titre_image_redacteur_02' => 'Editor',
'titre_image_visiteur' => 'Pengunjung',
'titre_joindre_document' => 'LAMPIRKAN SEBUAH DOKUMEN',
'titre_liens_entrants' => 'Tautan masuk',
'titre_mots_cles' => 'KATA-KATA KUNCI',
'titre_probleme_technique' => 'Peringatan: sebuah permasalahan teknis (server SQL) telah mengganggu akses ke bagian situs ini.<p>Terima kasih atas pengertian anda.',
'titre_publier_document' => 'PUBLIKASI DOKUMEN DI BAGIAN INI',
'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
'titre_signatures_confirmees' => 'Signatures confirm&eacute;es', # NEW
'titre_statistiques' => 'Statistik situs',
'titre_titre_document' => 'Judul dokumen:',
'todo' => '&agrave; venir', # NEW
'trad_reference' => '(rujuk artikel)',

// Z
'zbug_balise_b_aval' => ': tag B terlambat dalam loop',
'zbug_balise_inexistante' => 'Balise @balise@ mal d&eacute;clar&eacute;e pour @from@', # NEW
'zbug_balise_sans_argument' => 'Argument manquant dans la balise @balise@', # NEW
'zbug_boucle' => 'loop',
'zbug_boucle_recursive_undef' => 'loop rekursif yang tak terdefinisi', # MODIF
'zbug_calcul' => 'calcul', # NEW
'zbug_champ_hors_boucle' => 'Kolom @champ@ di luar loop',
'zbug_champ_hors_motif' => 'Kolom @champ@ di luar loop bertag @motif@', # MODIF
'zbug_code' => 'kode',
'zbug_critere_inconnu' => 'kriteria yang tidak dikenal @critere@', # MODIF
'zbug_distant_interdit' => 'data eksternal dilarang', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Doublons sur une table sans clef primaire atomique', # NEW
'zbug_doublon_table_sans_index' => 'ganda dalam sebuah tabel tanpa indeks', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: definisi ganda', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: tag penutup hilang', # MODIF
'zbug_erreur_boucle_syntaxe' => 'Sintaks (BOUCLE) loop yang salah ', # MODIF
'zbug_erreur_compilation' => 'Kesalahan kompilasi',
'zbug_erreur_execution_page' => 'kesalahan dalam kalkulasi halaman', # MODIF
'zbug_erreur_filtre' => 'Kesalahan - filter yang tak terdefinisi: <b>"@filtre@"</b>', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} hanya berlaku untuk loop (FORUM) and (RUBRIK)', # MODIF
'zbug_erreur_squelette' => 'Kesalahan dalam templat',
'zbug_hors_compilation' => 'Hors Compilation', # NEW
'zbug_info_erreur_squelette' => '&#1615;Kesalahan di situs',
'zbug_inversion_ordre_inexistant' => 'susunan yang tidak dikenal', # MODIF
'zbug_pagination_sans_critere' => 'Tag #PAGINATION tanpa kriteria (penomoran halaman), atau digunakan dalam loop rekursif', # MODIF
'zbug_parametres_inclus_incorrects' => 'Parameter-parameter tambahan yang salah', # MODIF
'zbug_profile' => 'Waktu kalkulasi: @time@',
'zbug_resultat' => 'hasil',
'zbug_serveur_indefini' => 'server SQL yang tidak dikenal', # MODIF
'zbug_statistiques' => 'Statistiques des requ&ecirc;tes SQL class&eacute;es par dur&eacute;e', # NEW
'zbug_table_inconnue' => 'Tabel SQL yang tidak dikenal "@table@"',
'zxml_connus_attributs' => 'atribut yang dikenal',
'zxml_de' => 'dari',
'zxml_inconnu_attribut' => 'atribut yang tidak dikenal',
'zxml_inconnu_balise' => 'tag yang tidak dikenal',
'zxml_inconnu_entite' => 'entitas yang tidak dikenal',
'zxml_inconnu_id' => 'ID yang tidak dikenal',
'zxml_mais_de' => 'tapi dari',
'zxml_non_conforme' => 'tidak sesuai dengan prinsipal',
'zxml_non_fils' => 'bukan turunan dari',
'zxml_nonvide_balise' => 'tag tidak kosong',
'zxml_obligatoire_attribut' => 'atribut yang dibutuhkan tidak ditemukan dalam',
'zxml_succession_fils_incorrecte' => 'turunan yang salah',
'zxml_survoler' => 'untuk melihat entri yang benar, cukup letakkan kursor di atasnya',
'zxml_valeur_attribut' => 'nilai atribut',
'zxml_vide_balise' => 'tag kosong',
'zxml_vu' => 'dilihat sebelumnya'
);

?>
